Write documentation without type annotations and examples.

Assume that the reader of the documentation has a mathematical background.

Add the type annotation that tests return `None` for generated tests.

Don't comment the code.

Don't give default values in function documentation.
